package cd.casic.pipeline.commons.operationid;


import cd.casic.framework.commons.exception.ServiceException;
import cd.casic.framework.commons.exception.enums.GlobalErrorCodeConstants;
import cd.casic.framework.commons.util.date.DateUtils;
import cd.casic.framework.mybatis.core.query.LambdaQueryWrapperX;
import cd.casic.pipeline.commons.operationid.entity.LeafAlloc;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author by mianbin
 * @Classname LeafAllocServiceImpl
 * @Description TODO
 * @Date 2025/3/19 10:41
 */
@Slf4j
@Service
public class LeafAllocServiceImpl implements LeafAllocService {

    @Resource
    private LeafAllocMapper leafAllocMapper;

    @Override
    public List<LeafAlloc> getAllLeafAllocs() {
        List<LeafAlloc> leafAllocs = leafAllocMapper.selectList();
        return CollUtil.emptyIfNull(leafAllocs);
    }

    @Override
    public LeafAlloc updateMaxIdAndGetLeafAlloc(String key) {
        LeafAlloc leafAlloc = leafAllocMapper.selectOne(LeafAlloc::getKey, key);
        leafAlloc.setMaxId(leafAlloc.getMaxId() + leafAlloc.getStep());
        return leafAllocMapper.updateById(leafAlloc) > 0 ? leafAlloc : null;
    }

    @Override
    public LeafAlloc updateMaxIdByCustomStepAndGetLeafAlloc(LeafAlloc condition) {
        LambdaQueryWrapper<LeafAlloc> wrapper = Wrappers.<LeafAlloc>lambdaQuery().eq(LeafAlloc::getKey, condition.getKey());
        condition.setMaxId(condition.getMaxId() + condition.getStep());
        return leafAllocMapper.updateById(condition) > 0 ? condition : null;
    }

    @Override
    public List<String> getAllKeys() {
        return leafAllocMapper.selectList().stream().map(LeafAlloc::getKey).collect(Collectors.toList());
    }

    @Override
    public boolean create(LeafAlloc leafAlloc) {
        LeafAlloc one = leafAllocMapper.selectOne(LeafAlloc::getKey, leafAlloc.getKey());
        if (one != null) {
            throw new ServiceException(GlobalErrorCodeConstants.ID_DUPLICATION);
        }
        return leafAllocMapper.insert(leafAlloc) > 0 ? true : false;
    }

    @Override
    public boolean update(LeafAlloc leafAlloc) {
        LeafAlloc one = leafAllocMapper.selectOne(LeafAlloc::getKey, leafAlloc.getKey(), LeafAlloc::getId, leafAlloc.getId());
        if (one != null) {
            throw new ServiceException(GlobalErrorCodeConstants.ID_DUPLICATION);
        }
        one.setUpdateTime(DateUtil.toLocalDateTime(new Date()));
        return leafAllocMapper.updateById(one) > 0 ? true : false;
    }

    @Override
    public boolean batchCreate(List<LeafAlloc> leafAllocs) {
        return leafAllocMapper.insertBatch(leafAllocs);
    }
}
