package cd.casic.pipeline.commons.operationid.entity;

import cd.casic.framework.commons.util.validation.ValidGroup;
import cd.casic.framework.mybatis.core.dataobject.BaseDO;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Null;
import jakarta.validation.constraints.Size;
import lombok.Data;
import lombok.experimental.Accessors;

/**
 * @author mianbin
 * @Classname LeafAlloc
 * @Description 业务id实体
 * @Date 2025/3/18 14:16
 */
@Data
@Accessors(chain = true)
@Schema(description = "生成唯一id的实体")
public class LeafAlloc extends BaseDO {
    private static final long serialVersionUID = 1L;

    @Schema(description = "主键")
    @Null(message = "新增id需为空", groups = ValidGroup.Create.class)
    @NotNull(message = "修改id不能为空", groups = ValidGroup.Update.class)
    private String id;

    /**
     * 业务key
     */
    @Schema(description = "业务key", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotBlank(message = "key不能为空")
    private String key;

    /**
     * 当前已分配的最大id
     */
    @Schema(description = "当前已分配的最大id(新增建议从1开始)", requiredMode = Schema.RequiredMode.REQUIRED, defaultValue = "1")
    @NotNull(message = "maxId不能为空")
    @Size(min = 1, message = "最小为1")
    private Long maxId;

    /**
     * 初始步长，也是动态调整的最小步长
     */
    @Schema(description = "初始步长，也是动态调整的最小步长（从数据库一次获取的id数量）", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "step不能为空")
    @Size(min = 1, message = "最小为1")
    private Integer step;

    /**
     * 业务key描述
     */
    @Schema(description = "业务key描述", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    private String description;


}
